from django.test import TestCase

# Create your tests here.
from django.test.client import Client
from django.http import HttpResponse
import uuid

from ..status_code import *
from ..settings import *

class ChangePasswordTest(TestCase):
    def setUp(self):
        self.client = Client()
        
        self.url = "/api/accounts/change_password"
        
        self.username: str = str(uuid.uuid4())[:USERNAME_MAX_SIZE]
        self.password: str = str(uuid.uuid4())[:PASSWORD_MAX_SIZE]
        self.new_password: str = str(uuid.uuid4())[:PASSWORD_MAX_SIZE]
        
        self.client.post("/api/accounts/register",  {"username": self.username, "password": self.password})
    
    def test_normal_login(self):
        response: HttpResponse = self.client.post("/api/accounts/login",  {"username": self.username, "password": self.password})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, USER_VALID)

    def test_invalid_username(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.password, "password": self.password})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_invalid_password(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username, "password": self.username})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_invalid_no_username(self):
        response: HttpResponse = self.client.post(self.url,  {"password": self.password})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_invalid_no_password(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_invalid_no_password(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_invalid_no_password_no_username(self):
        response: HttpResponse = self.client.post(self.url,  {})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)
    
    def test_no_new_password(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username, "current_password": self.password})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_new_password_to_short(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username, "current_password": self.password, "new_password": "a" * (PASSWORD_MIN_SIZE - (PASSWORD_MIN_SIZE > 0))})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_new_password_to_long(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username, "current_password": self.password, "new_password": "a" * (PASSWORD_MAX_SIZE + 1)})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_normal_change_password(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username, "current_password": self.password, "new_password": self.new_password})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, PASSWORD_UPDATED)