from django.test import TestCase

# Create your tests here.
from django.test.client import Client
from django.http import HttpResponse
import uuid

from ..status_code import *
from ..settings import *

class DeleteTest(TestCase):
    def setUp(self):
        self.client = Client()
        
        self.url = "/api/accounts/delete"
        
        self.username: str = str(uuid.uuid4())[:USERNAME_MAX_SIZE]
        self.password: str = str(uuid.uuid4())[:PASSWORD_MAX_SIZE]
        
        self.client.post("/api/accounts/register",  {"username": self.username, "password": self.password})

    def test_invalid_username(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.password, "password": self.password})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_invalid_password(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username, "password": self.username})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_invalid_no_username(self):
        response: HttpResponse = self.client.post(self.url,  {"password": self.password})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_invalid_no_password(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_invalid_no_password(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_invalid_no_password_no_username(self):
        response: HttpResponse = self.client.post(self.url,  {})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)
    
    def test_normal_delete(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username, "password": self.password})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, USER_DELETED)