from django.test import TestCase

# Create your tests here.
from django.test.client import Client
from django.http import HttpResponse
import uuid

from ..status_code import *
from ..settings import *

class RegisterTest(TestCase):
    def setUp(self):
        self.client = Client()

        self.url: str = "/api/accounts/register"

        self.username: str = str(uuid.uuid4())[:USERNAME_MAX_SIZE]
        self.password: str = str(uuid.uuid4())[:PASSWORD_MAX_SIZE]

    def test_incomplet_form_no_username_no_password(self):
        response: HttpResponse = self.client.post(self.url)
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_incomplet_form_no_password(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_incomplet_form_no_username(self):
        response: HttpResponse = self.client.post(self.url,  {"password": self.password})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, "error: username invalid")
    
    def test_incomplet_form_no_username(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_normal_register(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username, "password": self.password})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, USER_ADDED)

    def test_username_too_short(self):
        response: HttpResponse = self.client.post(self.url,  {"username": "a" * (USERNAME_MIN_SIZE - (USERNAME_MIN_SIZE > 0)), "password": self.password})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_username_too_long(self):
        response: HttpResponse = self.client.post(self.url,  {"username": "a" * (USERNAME_MAX_SIZE + 1), "password": self.password})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_password_too_short(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username, "password": "a" * (PASSWORD_MIN_SIZE - (PASSWORD_MIN_SIZE > 0))})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)

    def test_password_too_long(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username, "password": "a" * (PASSWORD_MAX_SIZE + 1)})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, INVALID_USERNAME_PASSWORD)
        
    def test_already_registered(self):
        self.client.post(self.url,  {"username": self.username, "password": self.password})
        response: HttpResponse = self.client.post(self.url,  {"username": self.username, "password": self.password})
        response_text: str = response.content.decode("utf-8")
        self.assertEqual(response_text, USERNAME_ALREADY_USED)